import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'fixtureName',
    label: '工具名称'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'borrowDept',
    label: '借用部门'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'borrowUser',
    label: '借用人'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.FIXTURE_BORROW_RECORD_STATUS)
    },
    fieldName: 'status',
    label: '借用状态'
  },
  {
    component: 'RangePicker',
    fieldName: 'borrowTime',
    label: '借用时间'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '工具名称',
    field: 'fixtureName',
    minWidth: 100,
    fixed: 'left',
    slots: { default: 'fixtureName' }
  },
  {
    title: '借用状态',
    field: 'status',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.status === null || row.status === '') {
          return '';
        }
        return renderDict(row.status, DictEnum.FIXTURE_BORROW_RECORD_STATUS);
      }
    },
    minWidth: 100,
    fixed: 'left'
  },
  {
    title: '借用部门',
    field: 'borrowDeptName',
    minWidth: 120
  },
  {
    title: '借用人',
    field: 'borrowUserName',
    minWidth: 100
  },
  {
    title: '经办人',
    field: 'agentUserName',
    minWidth: 100
  },
  {
    title: '借用时间',
    field: 'borrowTime',
    minWidth: 120
  },
  {
    title: '借用原因',
    field: 'borrowReason',
    minWidth: 140
  },
  {
    title: '预计归还时间',
    field: 'planReturnTime',
    minWidth: 160
  },
  {
    title: '实际归还时间',
    field: 'returnTime',
    minWidth: 160
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];
export const customColumns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '工具名称',
    field: 'fixtureName',
    minWidth: 100,
    fixed: 'left',
    slots: { default: 'fixtureName' }
  },
  {
    title: '借用状态',
    field: 'status',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.status === null || row.status === '') {
          return '';
        }
        return renderDict(row.status, DictEnum.FIXTURE_BORROW_RECORD_STATUS);
      }
    },
    minWidth: 100,
    fixed: 'left'
  },
  {
    title: '借用部门',
    field: 'borrowDeptName',
    minWidth: 120
  },
  {
    title: '借用人',
    field: 'borrowUserName',
    minWidth: 100
  },
  {
    title: '经办人',
    field: 'agentUserName',
    minWidth: 100
  },
  {
    title: '借用时间',
    field: 'borrowTime',
    minWidth: 120
  },
  {
    title: '借用原因',
    field: 'borrowReason',
    minWidth: 140
  },
  {
    title: '预计归还时间',
    field: 'planReturnTime',
    minWidth: 160
  },
  {
    title: '实际归还时间',
    field: 'returnTime',
    minWidth: 160
  }
];



export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'fixtureId',
    label: '工具id',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'fixtureName',
    label: '工具名称',
    rules: 'required'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'borrowDept',
    label: '借用部门',
    rules: 'selectRequired'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'borrowUser',
    label: '借用人',
    rules: 'required'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'agentUser',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    label: '经办人'
  },
  {
    component: 'Input',
    fieldName: 'agentUserName',
    label: '经办人',
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.FIXTURE_BORROW_RECORD_STATUS),
      optionType: 'button'
    },
    defaultValue: '0',
    fieldName: 'status',
    label: '借用状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'borrowTime',
    label: '借用时间'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'borrowReason',
    label: '借用原因'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'planReturnTime',
    label: '预计归还时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'returnTime',
    label: '实际归还时间'
  }
];
